<?php

namespace Litecms\EmailTemplate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\EmailTemplate\Models\EmailTemplate;

class EmailTemplatePolicy
{

    /**
     * Determine if the given user can view the email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function view(UserPolicy $user, EmailTemplate $email_template)
    {
        if ($user->canDo('email_template.email_template.view') && $user->isAdmin()) {
            return true;
        }

        return $email_template->user_id == user_id() && $email_template->user_type == user_type();
    }

    /**
     * Determine if the given user can create a email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('email_template.email_template.create');
    }

    /**
     * Determine if the given user can update the given email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function update(UserPolicy $user, EmailTemplate $email_template)
    {
        if ($user->canDo('email_template.email_template.edit') && $user->isAdmin()) {
            return true;
        }

        return $email_template->user_id == user_id() && $email_template->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EmailTemplate $email_template)
    {
        return $email_template->user_id == user_id() && $email_template->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EmailTemplate $email_template)
    {
        if ($user->canDo('email_template.email_template.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given email_template.
     *
     * @param UserPolicy $user
     * @param EmailTemplate $email_template
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EmailTemplate $email_template)
    {
        if ($user->canDo('email_template.email_template.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
