<?php

namespace Litecms\EmailTemplate\Providers;

use Illuminate\Support\ServiceProvider;

class EmailTemplateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'email_template');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'email_template');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEmailTemplate();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEmailTemplate()
    {
        $this->app->bind('email_template', function($app) {
            return new EmailTemplate($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('EmailTemplate', 'Lavalite\EmailTemplate\Facades\EmailTemplate');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.email_template', function ($app) {
            return $this->app->make('Litecms\EmailTemplate\EmailTemplate');
        });

                // Bind EmailTemplate to repository
        $this->app->bind(
            'Litecms\EmailTemplate\Interfaces\EmailTemplateRepositoryInterface',
            \Litecms\EmailTemplate\Repositories\Eloquent\EmailTemplateRepository::class
        );

        $this->app->register(\Litecms\EmailTemplate\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\EmailTemplate\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and email_template's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/email_template.php', 'email_template'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEmailTemplate::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.email_template'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/email_template.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/email_template')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/email_template')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
